=== modified file 'client/errname.cc'
--- client/errname.cc	2010-09-08 22:31:17 +0000
+++ client/errname.cc	2010-10-31 21:54:29 +0000
@@ -735,7 +735,10 @@
     { "ER_UNKNOWN_SCHEMA_OPTION", 1699},
     { "ER_EVENT_OBSERVER_PLUGIN", 1700},
     { "ER_CORRUPT_SCHEMA_DEFINITION", 1701},
-    { "ER_UNUSED1702", 1702},
+    { "ER_OUT_OF_GLOBAL_SORTMEMORY", 1702},
+    { "ER_OUT_OF_GLOBAL_JOINMEMORY", 1703},
+    { "ER_OUT_OF_GLOBAL_READRNDMEMORY", 1704},
+    { "ER_OUT_OF_GLOBAL_READMEMORY", 1705},
     { 0, 0 }
   };
 

=== modified file 'docs/options.rst'
--- docs/options.rst	2010-09-30 16:54:59 +0000
+++ docs/options.rst	2010-11-01 18:01:56 +0000
@@ -178,8 +178,13 @@
 
   The size of the buffer that is used for full joins.
 
+.. option:: --join-buffer-constraint arg (=0)
+
+  A global constraint for join-buffer-size for all clients, cannot be set lower
+  than --join-buffer-size.  Setting to 0 means unlimited.
+
 .. Why is this a core arg?
-.. option:: --max-allowed-packet arg (=1M)
+.. option:: --max-allowed-packet arg (=64M)
 
   Max packetlength to send/receive from to server.
 
@@ -259,12 +264,22 @@
   each table it scans. If you do many sequential scans, you may want to
   increase this value.
 
+.. option:: --read-buffer-constraint arg (=0)
+
+  A global constraint for read-buffer-size for all clients, cannot be set lower
+  than --read-buffer-size.  Setting to 0 means unlimited.
+
 .. option:: --read-rnd-buffer-size arg (=262144)
 
   When reading rows in sorted order after a sort, the rows are read through
   this buffer to avoid a disk seeks. If not set, then it's set to the value of
   record_buffer.
 
+.. option:: --read-rnd-constraint arg (=0)
+
+  A global constraint for read-rnd-buffer-size for all clients, cannot be set
+  lower than --read-rnd-buffer-size.  Setting to 0 means unlimited.
+
 .. option:: --scheduler arg (=multi-thread)
 
   Select scheduler to be used.
@@ -273,6 +288,11 @@
 
   Each thread that needs to do a sort allocates a buffer of this size.
 
+.. option:: --sort-buffer-constraint arg (=0)
+
+  A global constraint for sort-buffer-size for all clients, cannot be set lower
+  than --sort-buffer-size.  Setting to 0 means unlimited.
+
 .. option:: --table-definition-cache arg (=128)
 
   The number of cached table definitions.

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-28 05:22:47 +0000
+++ drizzled/drizzled.cc	2010-11-03 11:01:55 +0000
@@ -66,6 +66,7 @@
 #include "drizzled/drizzled.h"
 #include "drizzled/module/registry.h"
 #include "drizzled/module/load_list.h"
+#include "drizzled/global_buffer.h"
 
 #include "drizzled/plugin/event_observer.h"
 
@@ -352,6 +353,11 @@
 
 atomic<uint32_t> connection_count;
 
+global_buffer_constraint<uint64_t> global_sort_buffer(0);
+global_buffer_constraint<uint64_t> global_join_buffer(0);
+global_buffer_constraint<uint64_t> global_read_rnd_buffer(0);
+global_buffer_constraint<uint64_t> global_read_buffer(0);
+
 /** 
   Refresh value. We use to test this to find out if a refresh even has happened recently.
 */
@@ -1300,6 +1306,9 @@
   N_("The maximum length of the result of function  group_concat."))
   ("join-buffer-size", po::value<uint64_t>(&global_system_variables.join_buff_size)->default_value(128*1024L)->notifier(&check_limits_join_buffer_size),
   N_("The size of the buffer that is used for full joins."))
+  ("join-heap-threshold",
+  po::value<uint64_t>()->default_value(0),
+  N_("A global cap on the amount of memory that can be allocated by session join buffers (0 means unlimited)"))
   ("max-allowed-packet", po::value<uint32_t>(&global_system_variables.max_allowed_packet)->default_value(64*1024*1024L)->notifier(&check_limits_map),
   N_("Max packetlength to send/receive from to server."))
   ("max-connect-errors", po::value<uint64_t>(&max_connect_errors)->default_value(MAX_CONNECT_ERRORS)->notifier(&check_limits_mce),
@@ -1353,16 +1362,25 @@
   N_("Each thread that does a sequential scan allocates a buffer of this "
       "size for each table it scans. If you do many sequential scans, you may "
       "want to increase this value."))
+  ("read-buffer-threshold",
+  po::value<uint64_t>()->default_value(0),
+  N_("A global cap on the size of read-buffer-size (0 means unlimited)"))
   ("read-rnd-buffer-size",
   po::value<uint32_t>(&global_system_variables.read_rnd_buff_size)->default_value(256*1024L)->notifier(&check_limits_read_rnd_buffer_size),
   N_("When reading rows in sorted order after a sort, the rows are read "
      "through this buffer to avoid a disk seeks. If not set, then it's set "
      "to the value of record_buffer."))
+  ("read-rnd-threshold",
+  po::value<uint64_t>()->default_value(0),
+  N_("A global cap on the size of read-rnd-buffer-size (0 means unlimited)"))
   ("scheduler", po::value<string>(),
   N_("Select scheduler to be used (by default multi-thread)."))
   ("sort-buffer-size",
   po::value<size_t>(&global_system_variables.sortbuff_size)->default_value(MAX_SORT_MEMORY)->notifier(&check_limits_sort_buffer_size),
   N_("Each thread that needs to do a sort allocates a buffer of this size."))
+  ("sort-heap-threshold",
+  po::value<uint64_t>()->default_value(0),
+  N_("A global cap on the amount of memory that can be allocated by session sort buffers (0 means unlimited)"))
   ("table-definition-cache", po::value<size_t>(&table_def_size)->default_value(128)->notifier(&check_limits_tdc),
   N_("The number of cached table definitions."))
   ("table-open-cache", po::value<uint64_t>(&table_cache_size)->default_value(TABLE_OPEN_CACHE_DEFAULT)->notifier(&check_limits_toc),
@@ -2256,6 +2274,58 @@
     exit(0);
   }
 
+  if (vm.count("sort-heap-threshold"))
+  {
+    if ((vm["sort-heap-threshold"].as<uint64_t>() > 0) and
+      (vm["sort-heap-threshold"].as<uint64_t>() < 
+      global_system_variables.sortbuff_size))
+    {
+      cout << N_("Error: sort-heap-threshold cannot be less than sort-buffer-size") << endl;
+      exit(-1);
+    }
+
+    global_sort_buffer.setMaxSize(vm["sort-heap-threshold"].as<uint64_t>());
+  }
+
+  if (vm.count("join-heap-threshold"))
+  {
+    if ((vm["join-heap-threshold"].as<uint64_t>() > 0) and
+      (vm["join-heap-threshold"].as<uint64_t>() <
+      global_system_variables.join_buff_size))
+    {
+      cout << N_("Error: join-heap-threshold cannot be less than join-buffer-size") << endl;
+      exit(-1);
+    }
+
+    global_join_buffer.setMaxSize(vm["join-heap-threshold"].as<uint64_t>());
+  }
+
+  if (vm.count("read-rnd-threshold"))
+  {
+    if ((vm["read-rnd-threshold"].as<uint64_t>() > 0) and
+      (vm["read-rnd-threshold"].as<uint64_t>() <
+      global_system_variables.read_rnd_buff_size))
+    {
+      cout << N_("Error: read-rnd-threshold cannot be less than read-rnd-buffer-size") << endl;
+      exit(-1);
+    }
+
+    global_read_rnd_buffer.setMaxSize(vm["read-rnd-threshold"].as<uint64_t>());
+  }
+
+  if (vm.count("read-buffer-threshold"))
+  {
+    if ((vm["read-buffer-threshold"].as<uint64_t>() > 0) and
+      (vm["read-buffer-threshold"].as<uint64_t>() <
+      global_system_variables.read_buff_size))
+    {
+      cout << N_("Error: read-buffer-threshold cannot be less than read-buffer-size") << endl;
+      exit(-1);
+    }
+
+    global_read_buffer.setMaxSize(vm["read-buffer-threshold"].as<uint64_t>());
+  }
+
   if (vm.count("exit-info"))
   {
     if (vm["exit-info"].as<long>())

=== modified file 'drizzled/drizzled.h'
--- drizzled/drizzled.h	2010-09-27 07:06:04 +0000
+++ drizzled/drizzled.h	2010-10-31 21:54:29 +0000
@@ -25,7 +25,8 @@
 #include <boost/program_options.hpp>
 
 #include "drizzled/atomics.h"
-
+#include "drizzled/global_buffer.h"
+#include "drizzled/definitions.h"
 struct passwd;
 
 namespace drizzled
@@ -47,6 +48,11 @@
 extern passwd *user_info;
 extern char *drizzled_user;
 
+extern global_buffer_constraint<uint64_t> global_sort_buffer;
+extern global_buffer_constraint<uint64_t> global_join_buffer;
+extern global_buffer_constraint<uint64_t> global_read_rnd_buffer;
+extern global_buffer_constraint<uint64_t> global_read_buffer;
+
 extern const char * const DRIZZLE_CONFIG_NAME;
 
 boost::program_options::variables_map &getVariablesMap();

=== modified file 'drizzled/enum.h'
--- drizzled/enum.h	2010-09-08 22:31:17 +0000
+++ drizzled/enum.h	2010-10-31 21:54:29 +0000
@@ -1044,7 +1044,11 @@
   ER_UNKNOWN_SCHEMA_OPTION,
   ER_EVENT_OBSERVER_PLUGIN,
   ER_CORRUPT_SCHEMA_DEFINITION,
-  ER_ERROR_LAST= ER_CORRUPT_SCHEMA_DEFINITION
+  ER_OUT_OF_GLOBAL_SORTMEMORY,
+  ER_OUT_OF_GLOBAL_JOINMEMORY,
+  ER_OUT_OF_GLOBAL_READRNDMEMORY,
+  ER_OUT_OF_GLOBAL_READMEMORY,
+  ER_ERROR_LAST= ER_OUT_OF_GLOBAL_READMEMORY
 };
 
 enum drizzle_exit_codes {

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-10-14 18:58:48 +0000
+++ drizzled/error.cc	2010-10-31 21:54:29 +0000
@@ -235,6 +235,10 @@
   add(ER_OPEN_AS_READONLY, N_("Table '%-.192s' is read only"));
   add(ER_OUTOFMEMORY, N_("Out of memory; restart server and try again (needed %lu bytes)"));
   add(ER_OUT_OF_SORTMEMORY, N_("Out of sort memory; increase server sort buffer size"));
+  add(ER_OUT_OF_GLOBAL_SORTMEMORY, N_("Global sort memory constraint hit; increase sort-heap-threshold"));
+  add(ER_OUT_OF_GLOBAL_JOINMEMORY, N_("Global join memory constraint hit; increase join-heap-threshold"));
+  add(ER_OUT_OF_GLOBAL_READRNDMEMORY, N_("Global read_rnd memory constraint hit; increase read-rnd-heap-threshold"));
+  add(ER_OUT_OF_GLOBAL_READMEMORY, N_("Global read memory constraint hit; increase read-buffer-threshold"));
   add(ER_UNEXPECTED_EOF, N_("Unexpected EOF found when reading file '%-.192s' (errno: %d)"));
   add(ER_CON_COUNT_ERROR, N_("Too many connections"));
   add(ER_OUT_OF_RESOURCES, N_("Out of memory; check if drizzled or some other process uses all available memory; if not, you may have to use 'ulimit' to allow drizzled to use more memory or you can add more swap space"));

=== modified file 'drizzled/filesort.cc'
--- drizzled/filesort.cc	2010-10-30 01:19:00 +0000
+++ drizzled/filesort.cc	2010-11-01 22:04:06 +0000
@@ -29,6 +29,7 @@
 #include <queue>
 #include <algorithm>
 
+#include "drizzled/drizzled.h"
 #include "drizzled/sql_sort.h"
 #include "drizzled/error.h"
 #include "drizzled/probes.h"
@@ -41,6 +42,8 @@
 #include "drizzled/internal/my_sys.h"
 #include "plugin/myisam/myisam.h"
 #include "drizzled/plugin/transactional_storage_engine.h"
+#include "drizzled/atomics.h"
+#include "drizzled/global_buffer.h"
 
 using namespace std;
 
@@ -136,8 +139,9 @@
                  bool sort_positions, ha_rows *examined_rows)
 {
   int error;
-  uint32_t memavl, min_sort_memory;
+  uint32_t memavl= 0, min_sort_memory;
   uint32_t maxbuffer;
+  size_t allocated_sort_memory= 0;
   buffpek *buffpek_inst;
   ha_rows records= HA_POS_ERROR;
   unsigned char **sort_keys= 0;
@@ -247,10 +251,20 @@
     uint32_t old_memavl;
     uint32_t keys= memavl/(param.rec_length+sizeof(char*));
     param.keys= (uint32_t) min(records+1, (ha_rows)keys);
+
+    allocated_sort_memory= param.keys * param.rec_length;
+    if (not global_sort_buffer.add(allocated_sort_memory))
+    {
+      my_error(ER_OUT_OF_GLOBAL_SORTMEMORY, MYF(ME_ERROR+ME_WAITTANG));
+      goto err;
+    }
+
     if ((table_sort.sort_keys=
 	 (unsigned char **) make_char_array((char **) table_sort.sort_keys,
                                             param.keys, param.rec_length)))
       break;
+
+    global_sort_buffer.sub(allocated_sort_memory);
     old_memavl= memavl;
     if ((memavl= memavl/4*3) < min_sort_memory && old_memavl > min_sort_memory)
       memavl= min_sort_memory;
@@ -261,6 +275,7 @@
     my_error(ER_OUT_OF_SORTMEMORY,MYF(ME_ERROR+ME_WAITTANG));
     goto err;
   }
+
   if (open_cached_file(&buffpek_pointers,drizzle_tmpdir.c_str(),TEMP_PREFIX,
 		       DISK_BUFFER_SIZE, MYF(MY_WME)))
     goto err;
@@ -357,6 +372,7 @@
     session->status_var.filesort_rows+= (uint32_t) records;
   }
   *examined_rows= param.examined_rows;
+  global_sort_buffer.sub(allocated_sort_memory);
   memcpy(&table->sort, &table_sort, sizeof(filesort_info));
   DRIZZLE_FILESORT_DONE(error, records);
   return (error ? HA_POS_ERROR : records);

=== added file 'drizzled/global_buffer.h'
--- drizzled/global_buffer.h	1970-01-01 00:00:00 +0000
+++ drizzled/global_buffer.h	2010-11-01 22:14:18 +0000
@@ -0,0 +1,69 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_GLOBAL_BUFFER_H
+#define DRIZZLED_GLOBAL_BUFFER_H
+
+#include <drizzled/atomics.h>
+
+namespace drizzled
+{
+template <class T>
+class global_buffer_constraint
+{
+public:
+  global_buffer_constraint(T max)
+  {
+    setMaxSize(max); 
+  }
+
+  T getMaxSize() const { return max_size; }
+  void setMaxSize(T new_size) 
+  {
+    if (new_size == 0) new_size = std::numeric_limits<T>::max(); 
+    max_size= new_size;
+  }
+
+  bool add(T addition)
+  {
+    if (current_size.add_and_fetch(addition) > max_size)
+    {
+      current_size.add_and_fetch(T(0) - addition);
+      return false;
+    }
+    return true;
+  }
+
+  bool sub(T subtract)
+  {
+    if (current_size < subtract)
+      return false;
+    else
+      current_size.add_and_fetch(T(0) - subtract);
+
+    return true;
+  }
+
+private:
+  atomic<T> current_size;
+  T max_size;
+};
+
+}
+#endif /* DRIZZLED_GLOBAL_BUFFER_H */

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-10-28 05:22:47 +0000
+++ drizzled/include.am	2010-11-01 22:04:06 +0000
@@ -190,6 +190,7 @@
 			      drizzled/generator/session.h \
 			      drizzled/generator/table.h \
 			      drizzled/gettext.h \
+			      drizzled/global_buffer.h \
 			      drizzled/global_charset_info.h \
 			      drizzled/ha_statistics.h \
 			      drizzled/handler_structs.h \

=== modified file 'drizzled/internal/mf_iocache.cc'
--- drizzled/internal/mf_iocache.cc	2010-10-10 08:28:30 +0000
+++ drizzled/internal/mf_iocache.cc	2010-10-31 21:54:29 +0000
@@ -51,6 +51,7 @@
 
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/m_string.h"
+#include "drizzled/drizzled.h"
 #ifdef HAVE_AIOWAIT
 #include "drizzled/error.h"
 #include "drizzled/internal/aio_result.h"
@@ -247,6 +248,12 @@
       if (cachesize < min_cache)
 	cachesize = min_cache;
       buffer_block= cachesize;
+      if ((type == READ_CACHE) and (not global_read_buffer.add(buffer_block)))
+      {
+        my_error(ER_OUT_OF_GLOBAL_READMEMORY, MYF(ME_ERROR+ME_WAITTANG));
+        return 2;
+      }
+
       if ((info->buffer=
 	   (unsigned char*) malloc(buffer_block)) != 0)
       {
@@ -255,8 +262,14 @@
 	break;					/* Enough memory found */
       }
       if (cachesize == min_cache)
+      {
+        if (type == READ_CACHE)
+          global_read_buffer.sub(buffer_block);
 	return(2);				/* Can't alloc cache */
+      }
       /* Try with less memory */
+      if (type == READ_CACHE)
+        global_read_buffer.sub(buffer_block);
       cachesize= (cachesize*3/4 & ~(min_cache-1));
     }
   }
@@ -928,6 +941,8 @@
   }
   if (info->alloced_buffer)
   {
+    if (info->type == READ_CACHE)
+      global_read_buffer.sub(info->buffer_length);
     info->alloced_buffer=0;
     if (info->file != -1)			/* File doesn't exist */
       error= my_b_flush_io_cache(info,1);

=== modified file 'drizzled/join_cache.cc'
--- drizzled/join_cache.cc	2010-07-30 20:31:19 +0000
+++ drizzled/join_cache.cc	2010-11-05 11:44:09 +0000
@@ -30,6 +30,8 @@
 #include "config.h"
 #include "drizzled/sql_select.h" /* include join.h */
 #include "drizzled/field/blob.h"
+#include "drizzled/drizzled.h"
+#include "drizzled/internal/my_sys.h"
 
 #include <algorithm>
 
@@ -87,6 +89,8 @@
   if (!(cache->field=(CacheField*)
         memory::sql_alloc(sizeof(CacheField)*(cache->fields+table_count*2)+(blobs+1)* sizeof(CacheField*))))
   {
+    size= cache->end - cache->buff;
+    global_join_buffer.sub(size);
     free((unsigned char*) cache->buff);
     cache->buff=0;
     return(1);
@@ -162,6 +166,11 @@
   cache->blobs= blobs;
   *blob_ptr= NULL;					/* End sequentel */
   size= max((size_t) session->variables.join_buff_size, (size_t)cache->length);
+  if (not global_join_buffer.add(size))
+  {
+    my_error(ER_OUT_OF_GLOBAL_JOINMEMORY, MYF(ME_ERROR+ME_WAITTANG));
+    return 1;
+  }
   if (!(cache->buff= (unsigned char*) malloc(size)))
     return 1;
   cache->end= cache->buff+size;

=== modified file 'drizzled/records.cc'
--- drizzled/records.cc	2010-10-20 20:25:52 +0000
+++ drizzled/records.cc	2010-11-01 22:04:06 +0000
@@ -27,6 +27,7 @@
 #include "drizzled/optimizer/range.h"
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/iocache.h"
+#include "drizzled/drizzled.h"
 
 namespace drizzled
 {
@@ -172,6 +173,7 @@
 {                   /* free cache if used */
   if (cache)
   {
+    global_read_rnd_buffer.sub(session->variables.read_rnd_buff_size);
     free((char*) cache);
     cache= NULL;
   }
@@ -402,6 +404,12 @@
   local_rec_cache_size= cache_records * reclength;
   rec_cache_size= cache_records * ref_length;
 
+  if (not global_read_rnd_buffer.add(session->variables.read_rnd_buff_size))
+  {
+    my_error(ER_OUT_OF_GLOBAL_READRNDMEMORY, MYF(ME_ERROR+ME_WAITTANG));
+    return false;
+  }
+
   // We have to allocate one more byte to use uint3korr (see comments for it)
   if (cache_records <= 2 ||
       !(cache=(unsigned char*) malloc(local_rec_cache_size + cache_records * struct_length + 1)))

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-11-02 17:38:03 +0000
+++ drizzled/sql_select.cc	2010-11-05 11:44:09 +0000
@@ -51,6 +51,7 @@
 #include "drizzled/index_hint.h"
 #include "drizzled/records.h"
 #include "drizzled/internal/iocache.h"
+#include "drizzled/drizzled.h"
 
 #include "drizzled/sql_union.h"
 #include "drizzled/optimizer/key_field.h"
@@ -1216,7 +1217,11 @@
   delete quick;
   quick= 0;
   if (cache.buff)
+  {
+    size_t size= cache.end - cache.buff;
+    global_join_buffer.sub(size);
     free(cache.buff);
+  }
   cache.buff= 0;
   limit= 0;
   if (table)

=== added file 'tests/include/setup-global-constraints.inc'
--- tests/include/setup-global-constraints.inc	1970-01-01 00:00:00 +0000
+++ tests/include/setup-global-constraints.inc	2010-11-01 20:27:03 +0000
@@ -0,0 +1,32 @@
+--disable_warnings
+DROP TABLE IF EXISTS t1;
+DROP TABLE IF EXISTS t2;
+--enable_warnings
+
+CREATE TABLE `t1` (
+  `charcol1` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL,
+  `charcol2` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci;
+
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+
+CREATE TABLE t2 SELECT * FROM t1;

=== added file 'tests/r/global_read_constraints.result'
--- tests/r/global_read_constraints.result	1970-01-01 00:00:00 +0000
+++ tests/r/global_read_constraints.result	2010-11-01 20:27:03 +0000
@@ -0,0 +1,32 @@
+USE test;
+DROP TABLE IF EXISTS t1;
+DROP TABLE IF EXISTS t2;
+CREATE TABLE `t1` (
+`charcol1` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL,
+`charcol2` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci;
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+CREATE TABLE t2 SELECT * FROM t1;
+create temporary table t3 (a varchar(255), b varchar(255)) engine=myisam;
+insert into t3 select * from t1;
+select SQL_BIG_RESULT * from t3, (select * from t1) as t4;
+ERROR HY000: Global read memory constraint hit; increase read-buffer-threshold

=== added file 'tests/r/global_read_rnd_constraints.result'
--- tests/r/global_read_rnd_constraints.result	1970-01-01 00:00:00 +0000
+++ tests/r/global_read_rnd_constraints.result	2010-11-05 13:25:49 +0000
@@ -0,0 +1,1 @@
+USE test;

=== added file 'tests/r/global_sort_join_constraints.result'
--- tests/r/global_sort_join_constraints.result	1970-01-01 00:00:00 +0000
+++ tests/r/global_sort_join_constraints.result	2010-11-05 11:44:09 +0000
@@ -0,0 +1,30 @@
+USE test;
+DROP TABLE IF EXISTS t1;
+DROP TABLE IF EXISTS t2;
+CREATE TABLE `t1` (
+`charcol1` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL,
+`charcol2` VARCHAR(36) COLLATE utf8_general_ci DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci;
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+INSERT INTO t1 VALUES (UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID()),(UUID(), UUID());
+CREATE TABLE t2 SELECT * FROM t1;
+select SQL_BIG_RESULT * from t1 join t2 on (t1.charcol1 = t2.charcol2) join t2 as t3 on (t1.charcol1 = t3.charcol2);
+ERROR HY000: Global join memory constraint hit; increase join-heap-threshold

=== added file 'tests/t/global_read_constraints-master.opt'
--- tests/t/global_read_constraints-master.opt	1970-01-01 00:00:00 +0000
+++ tests/t/global_read_constraints-master.opt	2010-11-01 17:55:28 +0000
@@ -0,0 +1,1 @@
+--read-buffer-threshold=128k

=== added file 'tests/t/global_read_constraints.test'
--- tests/t/global_read_constraints.test	1970-01-01 00:00:00 +0000
+++ tests/t/global_read_constraints.test	2010-11-01 17:55:28 +0000
@@ -0,0 +1,9 @@
+# Setup table for tests
+USE test;
+
+--source include/setup-global-constraints.inc
+
+create temporary table t3 (a varchar(255), b varchar(255)) engine=myisam;
+insert into t3 select * from t1;
+--error 1705
+select SQL_BIG_RESULT * from t3, (select * from t1) as t4;

=== added file 'tests/t/global_read_rnd_constraints-master.opt'
--- tests/t/global_read_rnd_constraints-master.opt	1970-01-01 00:00:00 +0000
+++ tests/t/global_read_rnd_constraints-master.opt	2010-11-01 17:26:12 +0000
@@ -0,0 +1,1 @@
+--read-rnd-threshold=262144 

=== added file 'tests/t/global_read_rnd_constraints.test'
--- tests/t/global_read_rnd_constraints.test	1970-01-01 00:00:00 +0000
+++ tests/t/global_read_rnd_constraints.test	2010-11-05 12:57:13 +0000
@@ -0,0 +1,19 @@
+# Test is disabled because drizzleslap error code is now different on different platforms
+
+# Setup table for tests
+USE test;
+
+#--source include/setup-global-constraints.inc
+
+# We appear to need to beef up the table to use the read_rnd buffer at all
+#alter table t1 modify charcol1 varchar(255);
+#alter table t1 modify charcol2 varchar(255);
+#insert into t1 select SQL_BIG_RESULT * from t1;
+#insert into t1 select SQL_BIG_RESULT * from t1;
+#insert into t1 select SQL_BIG_RESULT * from t1;
+#insert into t1 select SQL_BIG_RESULT * from t1;
+#insert into t1 select SQL_BIG_RESULT * from t1;
+
+# Test for read_rnd buffer constraint
+#--error 134
+#--exec $DRIZZLE_SLAP -q "SELECT SQL_BIG_RESULT * FROM t1 ORDER BY 1" -c100 --iterations=1 --number-of-queries=1000 --create-schema=test

=== added file 'tests/t/global_sort_join_constraints-master.opt'
--- tests/t/global_sort_join_constraints-master.opt	1970-01-01 00:00:00 +0000
+++ tests/t/global_sort_join_constraints-master.opt	2010-11-01 17:26:12 +0000
@@ -0,0 +1,1 @@
+--join-heap-threshold=131072 --sort-heap-threshold=2097144

=== added file 'tests/t/global_sort_join_constraints.test'
--- tests/t/global_sort_join_constraints.test	1970-01-01 00:00:00 +0000
+++ tests/t/global_sort_join_constraints.test	2010-11-05 11:44:09 +0000
@@ -0,0 +1,13 @@
+# Setup table for tests
+USE test;
+
+--source include/setup-global-constraints.inc
+
+# Test for sort buffer constraint
+# Test disabled, needs two parallel filesorts to trigger error.  Drizzleslap's error handling currently unpredictable
+#--error 134
+#--exec $DRIZZLE_SLAP -q "SELECT * FROM t1 ORDER BY 1" -c100 --iterations=1 --number-of-queries=1000 --create-schema=test
+
+# Test for join buffer constraint
+--error 1703
+select SQL_BIG_RESULT * from t1 join t2 on (t1.charcol1 = t2.charcol2) join t2 as t3 on (t1.charcol1 = t3.charcol2);

=== modified file 'unittests/atomics_test.cc'
--- unittests/atomics_test.cc	2010-06-02 22:35:45 +0000
+++ unittests/atomics_test.cc	2010-10-20 09:32:35 +0000
@@ -78,8 +78,8 @@
 
   u235.fetch_and_store(100);
 
-  EXPECT_EQ(false, u235.compare_and_swap(42, 200));
-  EXPECT_EQ(true, u235.compare_and_swap(200, 100));
+  ASSERT_FALSE(u235.compare_and_swap(42, 200));
+  ASSERT_TRUE(u235.compare_and_swap(200, 100));
   EXPECT_EQ(200, u235);
 }
 

=== added file 'unittests/global_buffer_test.cc'
--- unittests/global_buffer_test.cc	1970-01-01 00:00:00 +0000
+++ unittests/global_buffer_test.cc	2010-10-20 09:34:21 +0000
@@ -0,0 +1,60 @@
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Andrew Hutchings
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <gtest/gtest.h>
+#include "drizzled/global_buffer.h"
+
+TEST(global_buffer, overflow)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  ASSERT_TRUE(test_buffer.add(512));
+  ASSERT_TRUE(test_buffer.add(512));
+  ASSERT_FALSE(test_buffer.add(1));
+}
+
+TEST(global_buffer, subtract)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  ASSERT_TRUE(test_buffer.add(1024));
+  ASSERT_TRUE(test_buffer.sub(512));
+  ASSERT_TRUE(test_buffer.add(512));
+  ASSERT_FALSE(test_buffer.add(1));
+}
+
+TEST(global_buffer, underflow)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  ASSERT_TRUE(test_buffer.add(10));
+  ASSERT_FALSE(test_buffer.sub(11));
+}
+
+TEST(global_buffer, change_max)
+{
+  drizzled::global_buffer_constraint<uint64_t> test_buffer(1024);
+
+  test_buffer.setMaxSize(512);
+
+  ASSERT_FALSE(test_buffer.add(513));
+}

=== modified file 'unittests/include.am'
--- unittests/include.am	2010-09-14 07:47:50 +0000
+++ unittests/include.am	2010-11-01 22:04:06 +0000
@@ -28,6 +28,7 @@
 			      unittests/date_test.cc \
 			      unittests/date_time_test.cc \
 			      unittests/generators.cc \
+                              unittests/global_buffer_test.cc \
                               unittests/libdrizzle_test.cc \
 			      unittests/main.cc \
 			      unittests/micro_timestamp_test.cc \

=== modified file 'unittests/pthread_atomics_test.cc'
--- unittests/pthread_atomics_test.cc	2010-06-02 22:35:45 +0000
+++ unittests/pthread_atomics_test.cc	2010-10-20 09:36:04 +0000
@@ -106,8 +106,8 @@
 
   u235.fetch_and_store(100);
 
-  EXPECT_EQ(false, u235.compare_and_swap(42, 200));
-  EXPECT_EQ(true, u235.compare_and_swap(200, 100));
+  ASSERT_FALSE(u235.compare_and_swap(42, 200));
+  ASSERT_TRUE(u235.compare_and_swap(200, 100));
   EXPECT_EQ(200, u235);
 }
 

=== modified file 'unittests/utf8_test.cc'
--- unittests/utf8_test.cc	2010-06-03 20:42:25 +0000
+++ unittests/utf8_test.cc	2010-10-20 09:36:04 +0000
@@ -29,10 +29,10 @@
 
 TEST(utf8, is_single)
 {
-  EXPECT_EQ(true, utf8::is_single('a'));
+  ASSERT_TRUE(utf8::is_single('a'));
   const char *multi_byte= "ç";
-  EXPECT_EQ(false, utf8::is_single(*multi_byte));
-  EXPECT_EQ(false, utf8::is_single(*(multi_byte + 1)));
+  ASSERT_FALSE(utf8::is_single(*multi_byte));
+  ASSERT_FALSE(utf8::is_single(*(multi_byte + 1)));
 }
 
 TEST(utf8, codepoint_length)

